Documentation
¶
Index ¶
Constants ¶
const (
MANAGED_TAG = "sshkeymgr:"
)
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type KeyData ¶
type KeyData struct {
// contains filtered or unexported fields
}
func LoadKeydata ¶
Parse the key from lines of data Expects 0 or more comment lines beginning with a # followed by a single line in authorized_keys format.
func ReadKeyDataFromReader ¶
Read a single key from a reader. This may advance past the end of the key
func ReadKeydataFromScanner ¶
Read a single key from a scanner. Leave the scanner at the next line (or EOF)
func (*KeyData) AddManagedComment ¶
func (kd *KeyData) AddManagedComment()
func (*KeyData) Equals ¶
Compare two KeyData instances. They compare as true iff the fingerprints of the keys match. Note that they explicitly *don't* care about options.
func (*KeyData) MatchesFingerprint ¶
type KeySet ¶
type KeySet struct {
Keys []*KeyData
}
func (*KeySet) RemoveKeyBySpec ¶
Removes any keys matching the keyspec. We expect either a public key or an MD5 or SHA256 based fingerprint. Returns true if found, false if not found
Click to show internal directories.
Click to hide internal directories.